import os

import arguing

from . import Database


def main():
    db_file = arguing.set('--database', mandatory=True, help='Database file.')

    if not os.path.exists(db_file):
        open(db_file, 'x').close()

    database = Database(open(db_file, 'wb'))

    while True:
        command = input('>>> ').lower()
        parsed = command.split()

        if not parsed:
            pass

        elif parsed[0] == 'exit':
            exit(0)

        elif parsed[0] in database.__dir__():
            try:
                output = database.__getattribute__(parsed[0])(*parsed[1:])

            except TypeError:
                output = database.__getattribute__(parsed[0])

            print(output)

        else:
            print('Unkown function/command.')


if __name__ == '__main__':
    main()



import hashlib
import os
import pickle
from io import TextIOWrapper
from typing import Any


class Database(object):

    def __init__(self, database: TextIOWrapper):
        self.size = os.path.getsize(database.name)
        self.database = pickle.load(database) if self.size else {}
        self.path = database.name

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_value, exc_traceback):
        self.dump()

    def __len__(self):
        return len(self.database)

    def set(self, key: str, value: Any, algo: str = None) -> None:
        if algo is not None and algo in hashlib.algorithms_available:
            hash_function = hashlib.__getattribute__(algo)
            value = hash_function(bytes(value, 'utf-8')).hexdigest()

        self.database[key] = value

    def get(self, key: str) -> Any:
        if key not in self.database:
            return None

        return self.database[key]

    def rename(self, key: str, name: str) -> None:
        if key in self.database:
            self.database[name] = self.database.pop(key)

    def remove(self, key: str) -> None:
        self.database.pop(key)

    def query(self, function: object) -> list:
        result = []

        for key, value in self.database.items():
            if function(key, value):
                result.append([key, value])

        return result

    def exists(self, key: str) -> bool:
        return key in self.database

    def dump(self) -> None:
        with open(self.path, 'wb') as file:
            pickle.dump(self.database, file)

    def population(self, key: str = None) -> int:
        if key is not None:
            return len(self.database[key])

        return len(self.database)

    def clear(self) -> None:
        self.database.clear()



from setuptools import setup, find_packages

long_description = open('./README.md')

setup(
    name='SonaDB',
    version='1.2.0',
    url='https://github.com/ZSendokame/SonaDB',
    license='MIT license',
    author='ZSendokame',
    description='Key-Value database library, small and easy to use.',
    long_description=long_description.read(),
    long_description_content_type='text/markdown',

    packages=(find_packages(include=['sona']))
)
